var EXPORTED_SYMBOLS = ["ConnectorFramework"];

Components.utils.import('resource://indexdata/runtime/core.js');
Components.utils.import('resource://indexdata/ui/app.js');
Components.utils.import('resource://indexdata/ui/repoClient.js');
Components.utils.import('resource://indexdata/ui/taskPane.js');
Components.utils.import('resource://indexdata/ui/jsButton.js');
Components.utils.import('resource://indexdata/ui/filterButton.js');
Components.utils.import('resource://indexdata/ui/UrlManipulator.js');

var ConnectorFramework = {
  app: app,
  core: core,
  repoClient: repoClient,
  taskPane: taskPane,
  filterButton: filterButton,
  jsButton: jsButton,
  openUrlManipulator: openUrlManipulator
};
